package biweekly.property;

import biweekly.Biweekly;

/*
 Copyright (c) 2013, Michael Angstadt
 All rights reserved.

 Redistribution and use in source and binary forms, with or without
 modification, are permitted provided that the following conditions are met: 

 1. Redistributions of source code must retain the above copyright notice, this
 list of conditions and the following disclaimer. 
 2. Redistributions in binary form must reproduce the above copyright notice,
 this list of conditions and the following disclaimer in the documentation
 and/or other materials provided with the distribution. 

 THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
 ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND
 ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

/**
 * <p>
 * Identifies the application that created the iCalendar object.
 * </p>
 * <p>
 * <b>Examples:</b>
 * 
 * <pre>
 * ProductId prodid = new ProductId(&quot;-//Company//Application Name//EN&quot;);
 * 
 * ICalendar ical = new ICalendar();
 * ical.setProductId(&quot;-//Company//Application Name//EN&quot;);
 * </pre>
 * 
 * </p>
 * @author Michael Angstadt
 * @see <a href="http://tools.ietf.org/html/rfc5545#page-78">RFC 5545 p.78-9</a>
 */
public class ProductId extends TextProperty {
	/**
	 * Creates a new product identifier property.
	 * @param value a unique string representing the application (e.g.
	 * "-//Company//Application Name//EN")
	 */
	public ProductId(String value) {
		super(value);
	}

	/**
	 * Creates a new product identifier property that represents this library.
	 * @return the property
	 */
	public static ProductId biweekly() {
		return new ProductId("-//Michael Angstadt//biweekly " + Biweekly.VERSION + "//EN");
	}
}
